@@ -28,7 +28,7 @@ class IndexManager(object):
                 name=value.get(u"name", u""),
                 comment=value.get(u"comment", u""),
                 product=value.get(u"reference product", u""),
-                categories="-".join(value.get(u"categories", u"")),
+                categories=u", ".join(value.get(u"categories", u"")),
                 location=value.get(u"location", u""),
                 database=key[0],
                 key=key[1]
